==> voltage-0.1.4a4.tar.gz: voltage-0.1.4a4/voltage/__init__.py <==
"""
-------
Voltage
-------

A Simple Pythonic Asynchronous API wrapper for Revolt.

=====
Usage
=====

.. code-block:: python3

    import voltage

    client = voltage.Client()

    @client.listen('ready')
    async def on_ready(payload):
        print(f"Logged in as {client.user}")

    @client.listen('message')
    async def on_message(message): # doesn't matter what you call the function.
        if message.content == '-ping':
            await message.channel.send('pong!')
        if message.content == '-embed':
            embed = voltage.SendableEmbed(title="Hello World", description="This is an embed")
            await message.reply(content="embed", embed=embed) # Obligatory message content.

    client.run("TOKEN")

=======
Credits
=======

    - **Contributers**, thank you :)

    - `Revolt.py <https://github.com/revoltchat/revolt.py>`_, When shit broke, that's where I went.

    - `Revolt.js <https://github.com/revoltchat/revolt.js>`_, When the docs fail you.

    - `Discord.py <https://github.com/Rapptz/discord.py>`_, Also a really great help while making this.

    - **Revolt development team**, Absolute chads.

"""

__title__ = "Voltage"
__author__ = "EnokiUN"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2021-present EnokiUN"
__version__ = "0.1.4a4"

from .asset import Asset, PartialAsset
from .categories import Category
from .channels import (
    Channel,
    DMChannel,
    GroupDMChannel,
    SavedMessageChannel,
    TextChannel,
    VoiceChannel,
    create_channel,
)
from .client import Client
from .embed import Embed, SendableEmbed
from .enums import AssetType, ChannelType, EmbedType, PresenceType, SortType
from .errors import HTTPError, VoltageException
from .file import File
from .invites import Invite
from .member import Member
from .message import Message, MessageMasquerade, MessageReply
from .messageable import Messageable
from .permissions import (
    ChannelPermissions,
    ServerPermissions,
    channel_permissions,
    server_permissions,
)
from .roles import Role
from .server import Server, ServerBan, SystemMessages
from .user import User

__all__ = [
    "Asset",
    "AssetType",
    "Channel",
    "ChannelType",
    "Client",
    "Category",
    "DMChannel",
    "Embed",
    "EmbedType",
    "File",
    "HTTPError",
    "Invite",
    "GroupDMChannel",
    "Member",
    "Message",
    "MessageMasquerade",
    "MessageReply",
    "Messageable",
    "PartialAsset",
    "PresenceType",
    "Role",
    "SavedMessageChannel",
    "SendableEmbed",
    "Server",
    "ServerBan",
    "ServerPermissions",
    "SavedMessageChannel",
    "SortType",
    "SystemMessages",
    "TextChannel",
    "VoiceChannel",
    "VoltageException",
    "channel_permissions",
    "server_permissions",
    "create_channel",
    "server_permissions",
]

==> voltage-0.1.5a1.tar.gz: voltage-0.1.5a1/voltage/__init__.py <==
"""
-------
Voltage
-------

A Simple Pythonic Asynchronous API wrapper for Revolt.

=====
Usage
=====

.. code-block:: python3

    import voltage

    client = voltage.Client()

    @client.listen('ready')
    async def on_ready(payload):
        print(f"Logged in as {client.user}")

    @client.listen('message')
    async def on_message(message): # doesn't matter what you call the function.
        if message.content == '-ping':
            await message.channel.send('pong!')
        if message.content == '-embed':
            embed = voltage.SendableEmbed(title="Hello World", description="This is an embed")
            await message.reply(content="embed", embed=embed) # Obligatory message content.

    client.run("TOKEN")

=======
Credits
=======

    - **Contributers**, thank you :)

    - `Revolt.py <https://github.com/revoltchat/revolt.py>`_, When shit broke, that's where I went.

    - `Revolt.js <https://github.com/revoltchat/revolt.js>`_, When the docs fail you.

    - `Discord.py <https://github.com/Rapptz/discord.py>`_, Also a really great help while making this.

    - **Revolt development team**, Absolute chads.

"""

# 2 = 1 # How's this haru?

# Edit: apparently defying the laws of math isn't enough to make all my problems dissappear and I have to expend some actual effort and time making my stuff works or else I get stupid errors, like WTF!

__title__ = "Voltage"
__author__ = "EnokiUN"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2021-present EnokiUN"
__version__ = "0.1.5a1"

from .asset import Asset, PartialAsset
from .categories import Category
from .channels import (
    Channel,
    DMChannel,
    GroupDMChannel,
    SavedMessageChannel,
    TextChannel,
    VoiceChannel,
    create_channel,
)
from .client import Client
from .embed import Embed, SendableEmbed
from .enums import (
    AssetType,
    ChannelType,
    EmbedType,
    PresenceType,
    RelationshipType,
    SortType,
)
from .errors import (
    CommandNotFound,
    HTTPError,
    MemberNotFound,
    NotEnoughArgs,
    UserNotFound,
    VoltageException,
)
from .file import File
from .invites import Invite
from .member import Member
from .message import Message, MessageMasquerade, MessageReply
from .messageable import Messageable
from .permissions import (
    ChannelPermissions,
    ServerPermissions,
    channel_permissions,
    server_permissions,
)
from .roles import Role
from .server import Server, ServerBan, SystemMessages
from .user import User

__all__ = [
    "Asset",
    "AssetType",
    "Channel",
    "ChannelPermissions",
    "ChannelType",
    "Client",
    "Category",
    "CommandNotFound",
    "DMChannel",
    "Embed",
    "EmbedType",
    "File",
    "HTTPError",
    "Invite",
    "GroupDMChannel",
    "Member",
    "MemberNotFound",
    "Message",
    "MessageMasquerade",
    "MessageReply",
    "Messageable",
    "NotEnoughArgs",
    "PartialAsset",
    "PresenceType",
    "Role",
    "RelationshipType",
    "SavedMessageChannel",
    "SendableEmbed",
    "Server",
    "ServerBan",
    "ServerPermissions",
    "SavedMessageChannel",
    "SortType",
    "SystemMessages",
    "TextChannel",
    "User",
    "UserNotFound",
    "VoiceChannel",
    "VoltageException",
    "channel_permissions",
    "server_permissions",
    "create_channel",
    "server_permissions",
]
